================================
Add Jupyter kernel with *poetry*
================================

The following command can be used to set up a Jupyter kernel within poetry

.. code:: bash

    poetry run python -m ipykernel install --user --name pymedphys
